@@ -1,4 +1,4 @@
-from util.console import Console
+from util import Console
 from validation import Validation
 
 from importlib import import_module
